pub fn dispatch_text_input(info: &InfoNode, event: InputTextEvent) -> boolExpand description
Sends an editing event to the focused text input, if one exists.
pub fn dispatch_text_input(info: &InfoNode, event: InputTextEvent) -> boolSends an editing event to the focused text input, if one exists.