hit_custom_node

Function hit_custom_node 

pub fn hit_custom_node<'a>(
    path: &'a HitPath<'a>,
) -> Option<&'a Arc<dyn CustomNode>>
Returns the innermost custom node on a hit path, if any.

The hit path is ordered child→parent, so the first Custom node found is the deepest node under the pointer.